@@ -13,18 +13,18 @@ import Language.Preprocessor.Cpphs.Options  (CpphsOptions(..), BoolOptions(..))
 import Language.Preprocessor.Unlit as Unlit (unlit)
 
 
-runCpphs :: CpphsOptions -> FilePath -> String -> String
-runCpphs options filename input =
-  let bools = boolopts options
+runCpphs :: CpphsOptions -> FilePath -> String -> IO String
+runCpphs options filename input = do
+  let bools  = boolopts options
       preInc = case preInclude options of
                  [] -> ""
                  is -> concatMap (\f->"#include \""++f++"\"\n") is 
                        ++ "#line 1 \""++filename++"\"\n"
 
-      pass1 = cppIfdef filename (defines options) (includes options) bools
-                       (preInc++input)
-      pass2 = macroPass (defines options) bools pass1
-      result= if not (macros bools) then unlines (map snd pass1) else pass2
+  pass1 <- cppIfdef filename (defines options) (includes options) bools
+                    (preInc++input)
+  pass2 <- macroPass (defines options) bools pass1
+  let result= if not (macros bools) then unlines (map snd pass1) else pass2
       pass3 = if literate bools then Unlit.unlit filename else id
 
-  in pass3 result
+  return (pass3 result)
